pub trait SettlementReader: Send + Sync {
// Required methods
fn is_settlement_ledger_applied_sync(
&self,
wallet: &WalletAddress,
symbol: &str,
) -> Result<bool>;
fn get_applied_settlement_symbols_sync(
&self,
wallet: &WalletAddress,
symbols: &[String],
) -> Result<HashSet<String>>;
fn get_total_fill_volume_sync(&self) -> Result<(i64, Decimal)>;
}Expand description
Read-only settlement queries.
Required Methods
Sourcefn is_settlement_ledger_applied_sync(
&self,
wallet: &WalletAddress,
symbol: &str,
) -> Result<bool>
fn is_settlement_ledger_applied_sync( &self, wallet: &WalletAddress, symbol: &str, ) -> Result<bool>
Check if a specific settlement has been applied to the ledger.
Sourcefn get_applied_settlement_symbols_sync(
&self,
wallet: &WalletAddress,
symbols: &[String],
) -> Result<HashSet<String>>
fn get_applied_settlement_symbols_sync( &self, wallet: &WalletAddress, symbols: &[String], ) -> Result<HashSet<String>>
Return the subset of symbols that have applied settlement payouts for a wallet.
Sourcefn get_total_fill_volume_sync(&self) -> Result<(i64, Decimal)>
fn get_total_fill_volume_sync(&self) -> Result<(i64, Decimal)>
Get total fill volume: (fill_count, total_notional).